@@ -178,12 +178,12 @@ build_model.matrix <- function(x, type = "relative", scaling = character(0L),
 #' @rdname build_model
 #' @param cols An `integer`/`character` vector giving the indices/names of the
 #' columns that should be considered as sequence data.
-#' Defaults to all columns, i.e., `seq(1, ncol(x))`.
+#' Defaults to all columns, i.e., `seq(1, ncol(x))`. Column names not found
+#' in `x` will be ignored without warning.
 build_model.stslist <- function(x, type = "relative", scaling = character(0L),
                                 cols = seq(1, ncol(x)), params = list(), ...) {
   check_missing(x)
   check_class(x, "stslist")
-  check_range(cols, type = "integer", scalar = FALSE, min = 1L, max = ncol(x))
   type <- check_model_type(type)
   scaling <- check_model_scaling(scaling)
   x <- create_seqdata(x, cols)
@@ -207,10 +207,9 @@ build_model.data.frame <- function(x, type = "relative",
                                    params = list(), ...) {
   check_missing(x)
   check_class(x, "data.frame")
-  check_range(cols, type = "integer", scalar = FALSE, min = 1L, max = ncol(x))
   type <- check_model_type(type)
   scaling <- check_model_scaling(scaling)
-  x <- create_seqdata(x, cols = cols)
+  x <- create_seqdata(x, cols)
   model <- initialize_model(x, type, scaling, params)
   build_model_(
     weights = model$weights,
@@ -324,6 +323,9 @@ build_model_ <- function(weights, inits = NULL, labels = NULL,
 #' @param alphabet Optional `character` vector of the alphabet.
 #' @noRd
 create_seqdata <- function(x, cols, alphabet) {
+  if (is.numeric(cols)) {
+    check_range(cols, scalar = FALSE, lower = 1L, upper = ncol(x))
+  }
   cols <- ifelse_(
     is.character(cols),
     which(names(x) %in% cols),
@@ -360,14 +362,14 @@ create_seqdata <- function(x, cols, alphabet) {
   )
   structure(
     as.matrix(x[, cols]),
-    class = c("matrix", "array"),
+    class = c("tna_seq_data", "matrix", "array"),
     alphabet = alphabet,
     labels = labels,
-    colors = colors#,
-    #cols = cols
+    colors = colors
   )
 }
 
+
 #' Compute Edge Weights from Sequence Data
 #'
 #' @param x A data object from `create_seqdata()`
