@@ -3,9 +3,9 @@
 #' @export
 #' @family basic
 #' @inheritParams graphics::hist
-#' @param ... Additional arguments passed to [graphics::hist()].
 #' @param main A `character` string defining the title of the plot.
 #' @param xlab A `character` string defining the vertical axis label.
+#' @param ... Additional arguments passed to [graphics::hist()].
 #' @return A `histogram` object of edge weights.
 #' @examples
 #' model <- tna(group_regulation)
@@ -22,9 +22,9 @@ hist.tna <- function(x, breaks, col = "lightblue",
     xlab <- paste0(
       "Edge Weights (",
       switch(type,
-        `relative` = "Probabilities",
-        `frequency` = "Frequencies",
-        `co-occurrence` = "Co-occurrences"
+             `relative` = "Probabilities",
+             `frequency` = "Frequencies",
+             `co-occurrence` = "Co-occurrences"
       ),
       ")"
     )
@@ -68,22 +68,32 @@ hist.tna <- function(x, breaks, col = "lightblue",
 #' @param colors See [qgraph::qgraph()].
 #' @param pie See [qgraph::qgraph()].
 #' @param cut Edge color and width emphasis cutoff value. The default is
-#' the median of the edge weights. See [qgraph::qgraph()] for details.
+#'   the median of the edge weights. See [qgraph::qgraph()] for details.
 #' @param show_pruned A `logical` value indicating if pruned edges removed by
-#' [prune()] should be shown in the plot.  The default is `TRUE`, and the
-#' edges are drawn as dashed with a different color to distinguish them.
+#'   [prune()] should be shown in the plot.  The default is `TRUE`, and the
+#'   edges are drawn as dashed with a different color to distinguish them.
 #' @param pruned_edge_color A `character` string for the color to use for
-#' pruned edges when `show_pruned = TRUE`. The default is `"pink"`.
+#'   pruned edges when `show_pruned = TRUE`. The default is `"pink"`.
 #' @param edge.color See [qgraph::qgraph()].
 #' @param edge.labels See [qgraph::qgraph()].
 #' @param edge.label.position See [qgraph::qgraph()].
 #' @param layout One of the following:
-#'   * A `character` string describing a `qgraph` layout.
+#'   * A `character` string describing a `qgraph` layout (e.g., `"circle"`)
+#'     or the name of a `igraph` layout function (e.g., `"layout_on_grid"`).
 #'   * A `matrix` of node positions to use, with a row for each node and
 #'     `x` and `y` columns for the node positions.
 #'   * A layout function from `igraph`.
 #' @param layout_args A `list` of arguments to pass to the `igraph` layout
-#'   function when `layout` is a function.
+#'   function when `layout` is a function or a character string that specifies
+#'   a function name.
+#' @param scale_nodes A `character` string giving the name of a centrality
+#'   measure to scale the node size by. See [centralities()] for valid names.
+#'   If missing (the default), uses default [qgraph::qgraph()] scaling.
+#'   Overrides `vsize` provided via `...`.
+#' @param scaling_factor A `numeric` value specifying how strongly to scale
+#'   the nodes when `scale_nodes` is provided. Values
+#'   between 0 and 1 will result in smaller differences and values larger
+#'   than 1 will result in greater differences. The default is `0.5`.
 #' @param mar See [qgraph::qgraph()].
 #' @param theme See [qgraph::qgraph()].
 #' @param ... Additional arguments passed to [qgraph::qgraph()].
@@ -96,14 +106,15 @@ plot.tna <- function(x, labels, colors, pie, cut,
                      show_pruned = TRUE, pruned_edge_color = "pink",
                      edge.color = NA, edge.labels = TRUE,
                      edge.label.position = 0.65, layout = "circle",
-                     layout_args = list(), mar = rep(5, 4),
-                     theme = "colorblind", ...) {
+                     layout_args = list(), scale_nodes, scaling_factor = 0.5,
+                     mar = rep(5, 4), theme = "colorblind", ...) {
   check_missing(x)
   check_class(x, "tna")
   check_flag(show_pruned)
   check_flag(edge.labels)
   check_range(edge.label.position, scalar = FALSE)
-  layout <- check_layout(x, layout, layout_args)
+  layout <- check_layout(x, layout = layout, layout_args)
+  vsize <- list(...)$vsize
   if (missing(pie)) {
     pie <- x$inits
   }
@@ -135,6 +146,15 @@ plot.tna <- function(x, labels, colors, pie, cut,
     attr(x, "pruning")$original,
     x$weights
   )
+  n <- nodes(x)
+  if (!missing(scale_nodes)) {
+    check_string(scale_nodes)
+    check_range(scaling_factor, lower = 0)
+    cent <- centralities(x, measures = scale_nodes, normalize = TRUE)[[2L]]
+    vsize <- rep(8 * exp(-n / 80)) * (1 + cent)^scaling_factor
+  } else {
+    vsize <- ifelse_(is.null(vsize), rep(8 * exp(-n / 80)), vsize)
+  }
   qgraph::qgraph(
     input = weights,
     color = colors,
@@ -144,6 +164,7 @@ plot.tna <- function(x, labels, colors, pie, cut,
     labels = labels,
     layout = layout,
     theme = theme,
+    vsize = vsize,
     pie = pie,
     mar = mar,
     lty = lty,
@@ -152,6 +173,7 @@ plot.tna <- function(x, labels, colors, pie, cut,
   )
 }
 
+
 #' Plot a Bootstrapped Transition Network Analysis Model
 #'
 #' @export
@@ -203,7 +225,7 @@ plot.tna_centralities <- function(x, reorder = TRUE, ncol = 3,
                                   scales = c("free_x", "fixed"),
                                   colors, labels = TRUE, ...) {
   check_class(x, "tna_centralities")
-  plot_centralities_(x, reorder, ncol, scales, colors, labels)
+  plot_centralities_(x, reorder, ncol, scales, colors, NULL, labels)
 }
 
 #' Plot Cliques of a TNA Network
@@ -564,7 +586,7 @@ plot.tna_permutation <- function(x, colors,
 #'
 plot.tna_stability <- function(x, level = 0.05, ...) {
   check_class(x, "tna_stability")
-  check_range(level)
+  check_range(level, lower = 0, upper = 1)
   x$detailed_results <- NULL
   x_names <- names(x)
   drop_prop <- attr(x, "drop_prop")
@@ -653,23 +675,22 @@ plot.tna_stability <- function(x, level = 0.05, ...) {
 #'
 #' @inheritParams plot.tna_centralities
 #' @noRd
-plot_centralities_ <- function(x, reorder, ncol, scales, colors, labels) {
+plot_centralities_ <- function(x, reorder, ncol, scales, colors,
+                               palette, labels) {
   check_flag(reorder)
   check_flag(labels)
   scales <- check_match(scales, c("free_x", "fixed"))
   scales <- ifelse_(scales == "free_x", "free", "free_y")
-  if (missing(colors) && !is.null(attr(x, "colors"))) {
-    colors <- attr(x, "colors")
-  }
-  if (missing(colors)) {
-    colors <- rep("black", length.out = length(unique(x$state)))
-  } else if (!is.list(colors) && length(colors) == 1) {
-    colors <- rep(colors, length.out = length(unique(x$state)))
-  }
+  n <- n_unique(x$state)
+  colors <- ifelse_(
+    missing(colors),
+    attr(x, "colors") %||% rep("black", n),
+    rep(colors, length.out = n)
+  )
   ifelse_(
     inherits(x, "tna_centralities"),
     plot_centralities_single(x, reorder, ncol, scales, colors, labels),
-    plot_centralities_multiple(x, reorder, ncol, scales, colors, labels)
+    plot_centralities_multiple(x, reorder, ncol, scales, colors, palette, labels)
   )
 }
 
@@ -747,10 +768,10 @@ plot_centralities_single <- function(x, reorder, ncol, scales, colors, labels) {
     ggplot2::ylab("")
 }
 
-plot_centralities_multiple <- function(x, reorder, ncol,
-                                       scales, colors, labels) {
+plot_centralities_multiple <- function(x, reorder, ncol, scales,
+                                       colors, palette = "Set2", labels) {
   measures <- names(x)[3:ncol(x)]
-  n_clusters <- length(unique(x$group))
+  n_clusters <- n_unique(x$group)
   x$state <- factor(x$state)
   x <- x |>
     data.frame() |>
@@ -763,26 +784,26 @@ plot_centralities_multiple <- function(x, reorder, ncol,
     )
   x$name <- factor(x$name, levels = measures)
   ggplot2::ggplot(x,
-      ggplot2::aes(
-        x = !!rlang::sym("value"),
-        y = !!rlang::sym("state"),
-        color = !!rlang::sym("group"),
-        fill = !!rlang::sym("group"),
-        group = !!rlang::sym("group")
-      )
-    ) +
+                  ggplot2::aes(
+                    x = !!rlang::sym("value"),
+                    y = !!rlang::sym("state"),
+                    color = !!rlang::sym("group"),
+                    fill = !!rlang::sym("group"),
+                    group = !!rlang::sym("group")
+                  )
+  ) +
     ggplot2::facet_wrap("name", ncol = ncol, scales = scales) +
     ggplot2::geom_path() +
     ifelse_(
-      !is.null(colors) & (length(unique(colors)) == n_clusters),
+      !is.null(colors) & (n_unique(colors) == n_clusters),
       ggplot2::scale_color_manual(values = colors),
-      ggplot2::scale_color_discrete()
+      ggplot2::scale_color_brewer(palette = palette)
     ) +
     ggplot2::geom_point(size = 2, shape = 21, stroke = NA) +
     ifelse_(
-      !is.null(colors) & (length(unique(colors)) == n_clusters),
+      !is.null(colors) & (n_unique(colors) == n_clusters),
       ggplot2::scale_fill_manual(values = colors),
-      ggplot2::scale_fill_discrete()
+      ggplot2::scale_fill_brewer(palette = palette)
     ) +
     ggplot2::theme_minimal() +
     ggplot2::xlab("Centrality") +
@@ -863,11 +884,19 @@ plot_compare.tna <- function(x, y, theme = NULL, palette = "colorblind",
 #' @export
 #' @family basic
 #' @param x A `tna` object created from sequence data.
+#' @param colors A `character` vector of colors to be used in the plot
+#'   (one per label) or a single color.
+#' @param width A `numeric` value for the Width of the bars. Default is 0.7,
+#' @param hjust A `numeric` value for the horizontal adjustment of the labels.
+#'   Default is 1.2.
+#' @param show_label A `logical` value indicating whether to show a label with
+#'   the frequency counts. Default is `TRUE`.
 #' @param ... Ignored.
 #' @return A `ggplot` object.
 #' @examples
 #' model <- tna(group_regulation)
 #' plot_frequencies(model)
+#' plot_frequencies(model, width =  0.5, colors = "pink")
 #'
 plot_frequencies <- function(x, ...) {
   UseMethod("plot_frequencies")
@@ -875,32 +904,63 @@ plot_frequencies <- function(x, ...) {
 
 #' @export
 #' @rdname plot_frequencies
-plot_frequencies.tna <- function(x, ...) {
+plot_frequencies.tna <- function(x, width = 0.7, hjust = 1.2,
+                                 show_label = TRUE, colors, ...) {
   check_missing(x)
   check_tna_seq(x)
-  #cols <- attr(x$data, "cols")
-  #tab <- table(unlist(x$data[, cols]))
+  check_values(width, type = "numeric")
+  check_numeric(hjust)
+  check_flag(show_label)
+  colors <- ifelse_(
+    missing(colors),
+    attr(x$data, "colors") %||% "black",
+    colors
+  )
+  n_colors <- length(colors)
+  n_labels <- length(x$labels)
+  stopifnot_(
+    n_colors == 1L || n_colors == n_labels,
+    "The number of {.arg colors} does not match
+     the number of labels in {.arg x}."
+  )
+  colors <- ifelse_(
+    n_colors == 1L,
+    rep(colors, n_labels),
+    colors
+  )
   tab <- table(unlist(x$data))
   d <- as.data.frame(tab)
   names(d) <- c("state", "freq")
-  d[[1L]] <- factor(x$labels[d[[1L]]])
-  ggplot2::ggplot(
+  d[[1L]] <- factor(x$labels[d[[1L]]], levels = rev(x$labels))
+  p <- ggplot2::ggplot(
     d,
-    ggplot2::aes(x = !!rlang::sym("state"), y = !!rlang::sym("freq"))
+    ggplot2::aes(y = !!rlang::sym("state"), x = !!rlang::sym("freq"))
   ) +
     ggplot2::geom_bar(
+      ggplot2::aes(fill = !!rlang::sym("state")),
       stat = "identity",
-      colour = "black",
-      width = 0.7
-    ) +
-    ggplot2::geom_text(
-      ggplot2::aes(label = !!rlang::sym("freq")),
-      position = ggplot2::position_dodge(width = 0.7),
-      vjust = -0.5
-    ) +
+      width = width
+    )
+
+  if (show_label) {
+    p <- p +
+      ggplot2::geom_text(
+        ggplot2::aes(label = !!rlang::sym("freq")),
+        position = ggplot2::position_dodge(width = width),
+        hjust = hjust
+      )
+  }
+  p +
     ggplot2::theme_minimal() +
-    ggplot2::scale_y_continuous(expand = ggplot2::expansion(mult = c(0, .1))) +
-    ggplot2::labs(x = "State", y = "Frequency")
+    ggplot2::scale_x_continuous(expand = ggplot2::expansion(mult = c(0, .1))) +
+    ggplot2::labs(y = "State", x = "Frequency") +
+    ggplot2::theme(
+      axis.title =  ggplot2::element_text(face = "bold"),
+      axis.text = ggplot2::element_text(color = "black"),
+      text = ggplot2::element_text(color = "black")
+    ) +
+    ggplot2::scale_fill_manual(values = colors) +
+    ggplot2::theme(legend.position = "none")
 }
 
 #' Plot a Transition Network Model from a Matrix of Edge Weights
@@ -1080,6 +1140,375 @@ plot_mosaic_ <- function(tab, digits, title, xlab, ylab) {
   out
 }
 
+#' Create a Sequence Index Plot or a Distribution Plot
+#'
+#' @export
+#' @rdname plot_sequences
+#' @param x A `tna`, `group_tna`, `tna_data` or a `data.frame` object with
+#'   sequence data in wide format.
+#' @param cols A `character` Vector of column names to be treated as
+#'   time points. If missing, all columns will be used.
+#' @param group A vector indicating the group assignment of each
+#'   row of the data. Must have the same length as the
+#'   number of rows of `x`. Alternatively, a single `character` string giving
+#'   the column name of the data that defines the group when `x` is a wide
+#'   format `data.frame` or a `tna_data` object. Used for faceting the plot.
+#' @param type A `character` string for the type of plot to generate. The
+#'   available options are  `"index"` (the default) for a sequence index plot,
+#'   and `"distribution"` showing the distribution of the states over time.
+#' @param scale A `character` string that determines the scaling of the
+#'   vertical axis for distribution plots. The options are `"proportion"`
+#'   (the default) and `"count"` for proportions and raw counts of states,
+#'   respectively.
+#' @param geom A `character` string for the type of geom to use for
+#'   distribution plots. The options are `"bar"` (the default) and `"area"`.
+#' @param include_na A `logical` value for whether to include missing values
+#'   for distribution plots. The default is `FALSE`. If `TRUE`, the missing
+#'   values are converted to a new state and included in the plot.
+#' @param colors A named `character` vector mapping states to colors, or an
+#'   unnamed `character` vector. If missing, a default palette is used.
+#' @param na_color A `character` string giving the color to use for missing
+#'   values. The default is `"white"`.
+#' @param sort_by Either a `character` vector of column names of `x` to sort
+#' by or `"everything"` to sort by every column.
+#' If missing, no sorting is done.
+#' @param show_n A `logical` value for whether to add the number of
+#'   observations (total or by group) to the plot title.
+#' @param border A `character` string giving the color for borders. For index
+#'   plots, this is the color of borders between cells (tiles). For
+#'   distribution plot with `geom = "bar"`, this is the color of bar outlines.
+#'   Not applicable to `geom = "area"`.
+#' @param title An optional `character` string providing a title for the plot.
+#' @param legend_title An optional `character` string providing a title for the
+#'   legend.
+#' @param xlab A `character` string giving the label for the horizontal axis.
+#'   The default is `"Time"`.
+#' @param ylab A `character` string giving the label for the vertical axis.
+#'   The default is `"Sequence"` for index plots, and `"Proportion"` or
+#'   `"Count"` based on `scale` for distribution plots.
+#' @param tick An `integer` specifying the horizontal axis label interval. The
+#' default value `tick = 5` shows every 5th label. Setting this to 1 will show
+#' every label.
+#' @param ncol Number of columns to use for the facets. The default is 2.
+#' @param ... Ignored.
+#' @examples
+#' # Sequence index plot (default)
+#' plot_sequences(
+#'   group_regulation,
+#'   group = rep(1:2, each = 1000),
+#' )
+#' # State distribution plot
+#' plot_sequences(
+#'   group_regulation,
+#'   group = rep(1:2, each = 1000),
+#'   type = "distribution",
+#' )
+#'
+plot_sequences <- function(x, ...) {
+  UseMethod("plot_sequences")
+}
+
+#' @export
+#' @rdname plot_sequences
+plot_sequences.tna <- function(x, group, type = "index",
+                               scale = "proportion", geom = "bar",
+                               include_na = FALSE, na_color = "white", sort_by,
+                               show_n = TRUE, border, title, legend_title,
+                               xlab, ylab, tick = 5, ncol = 2L, ...) {
+  check_missing(x)
+  check_tna_seq(x)
+  d <- as.data.frame(x$data)
+  cols <- names(d)
+  colors <- attr(x$data, "colors")
+  lab <- x$labels
+  lev <- seq_along(lab)
+  if (!missing(group)) {
+    stopifnot_(
+      length(group) == nrow(d),
+      "Argument {.arg group} must the same length as the number of rows in
+       the sequence data of {.arg x}."
+    )
+    d$.group <- group
+    group <- ".group"
+  }
+  plot_sequences_(
+    d, lev, lab, cols, group, type, scale, geom, include_na, colors,
+    na_color, sort_by, show_n, border, title, legend_title,
+    xlab, ylab, tick, ncol
+  )
+}
+
+#' @export
+#' @rdname plot_sequences
+plot_sequences.tna_data <- function(x, group, type = "index",
+                                    scale = "proportion",
+                                    geom = "bar", include_na = FALSE,
+                                    colors, na_color = "white", sort_by,
+                                    show_n = TRUE, border, title,
+                                    legend_title, xlab, ylab, tick = 5,
+                                    ncol = 2L, ...) {
+  check_missing(x)
+  check_class(x, "tna_data")
+  wide <- cbind(x$sequence_data, x$meta_data)
+  cols <- names(x$sequence_data)
+  plot_sequences.default(
+    wide, cols, group, type, scale, geom, include_na, colors, na_color,
+    sort_by, show_n, border, title, legend_title, xlab, ylab, tick, ncol
+  )
+}
+
+#' @export
+#' @rdname plot_sequences
+plot_sequences.default <- function(x, cols, group, type = "index",
+                                   scale = "proportion", geom = "bar",
+                                   include_na = FALSE, colors,
+                                   na_color = "white", sort_by,
+                                   show_n = TRUE, border, title,
+                                   legend_title, xlab, ylab, tick = 5,
+                                   ncol = 2L, ...) {
+  check_missing(x)
+  stopifnot_(
+    inherits(x, "stslist") || inherits(x, "data.frame"),
+    "Argument {.arg x} must be {.cls stslist} (sequence data) or a
+    {.cls data.frame} or object."
+  )
+  x_names <- names(x)
+  cols <- ifelse_(missing(cols), x_names, cols)
+  check_cols(cols, x_names)
+  if (!missing(group)) {
+    group_len <- length(group)
+    stopifnot_(
+      group_len == nrow(x) || group_len == 1L,
+      "Argument {.arg group} must be of length one or the same length as the
+       number of rows in {.arg x}."
+    )
+    if (group_len == 1L) {
+      stopifnot_(
+        group %in% x_names,
+        "Argument {.arg group} must be a column name of {.arg x}
+         when of length one."
+      )
+    } else {
+      x$.group <- group
+      group <- ".group"
+    }
+  }
+  lab <- ifelse_(
+    inherits(x, "stslist"),
+    attr(x, "alphabet"),
+    sort(unique(unlist(x[, cols])))
+  )
+  lev <- seq_along(lab)
+  x[cols] <- lapply(x[cols], factor)
+  x[cols] <- lapply(x[cols], as.integer)
+  plot_sequences_(
+    x, lev, lab, cols, group, type, scale, geom, include_na, colors,
+    na_color, sort_by, show_n, border, title, legend_title,
+    xlab, ylab, tick, ncol
+  )
+}
+
+plot_sequences_ <- function(x, lev, lab, cols, group, type, scale,
+                            geom, include_na, colors, na_color, sort_by,
+                            show_n, border, title, legend_title,
+                            xlab, ylab, tick, ncol) {
+  type <- check_match(type, c("distribution", "index"))
+  scale <- check_match(scale, c("count", "proportion"))
+  geom <- check_match(geom, c("area", "bar"))
+  check_flag(include_na)
+  check_flag(show_n)
+  check_values(tick)
+  has_group <- TRUE
+  if (missing(group)) {
+    x$.group <- 1L
+    group <- ".group"
+    has_group <- FALSE
+  }
+  x <- x |>
+    dplyr::select(c(dplyr::all_of(cols), !!rlang::sym(group))) |>
+    dplyr::group_by(!!rlang::sym(group))
+  if (!missing(sort_by)) {
+    if (is.numeric(sort_by)) {
+      x$.order <- sort_by
+      sort_cols <- ".order"
+    } else {
+      sort_cols <- ifelse_(
+        identical(sort_by, "everything"),
+        cols,
+        sort_by
+      )
+      check_cols(sort_cols, names(x))
+    }
+    x <- x |>
+      dplyr::arrange(dplyr::across(dplyr::all_of(sort_cols)), .by_group = TRUE)
+    # TODO more sorting options
+  }
+  x$.seq_id <- seq_len(nrow(x))
+  # Remove temporary grouping used in sorting
+  group <- ifelse_(has_group, group, rlang::missing_arg())
+  x <- x |> dplyr::ungroup()
+  long_data <- x |>
+    tidyr::pivot_longer(
+      cols = dplyr::all_of(cols),
+      names_to = "time",
+      values_to = "state"
+    ) |>
+    dplyr::mutate(
+      .seq_id = factor(!!rlang::sym(".seq_id")),
+      time = factor(!!rlang::sym("time"), levels = cols),
+      state = factor(!!rlang::sym("state"), levels = lev, labels = lab)
+    )
+  colors <- ifelse_(
+    missing(colors),
+    color_palette(n_unique(long_data$state)),
+    colors
+  )
+  if (show_n) {
+    if (!missing(group)) {
+      group_n <- x |>
+        dplyr::group_by(!!rlang::sym(group)) |>
+        dplyr::summarize(n = dplyr::n())
+      title_n <- paste0(
+        "{n[", seq_along(group_n$n), "] == ", group_n$n, "}",
+        collapse = " * \", \" * "
+      )
+      title_n <- paste0("\"(\" * ", title_n, " * \")\"")
+    } else {
+      title_n <- paste0("\"(\" * n == ", nrow(x), "* \")\"")
+    }
+  }
+  if (type == "index") {
+    create_index_plot(
+      long_data, group, colors, na_color, border,
+      title, include_na, title_n, legend_title, xlab, ylab, tick, ncol
+    )
+  } else {
+    create_distribution_plot(
+      long_data, group, scale, geom, include_na, colors, na_color,
+      border, title, title_n, legend_title, xlab, ylab, tick, ncol
+    )
+  }
+}
+
+create_index_plot <- function(x, group, colors, na_color, border, title, include_na,
+                              title_n, legend_title, xlab, ylab, tick, ncol) {
+  xlab <- ifelse_(missing(xlab), "Time", xlab)
+  ylab <- ifelse_(missing(ylab), "Sequence", ylab)
+  title <- ifelse_(missing(title), "\"Sequence Index Plot \"", title)
+  title <- str2expression(paste0(title, " * ", title_n))
+  legend_title <- ifelse_(missing(legend_title), NULL, legend_title)
+  every_nth <- function(y) y[(seq_along(y) - 1L) %% tick == 0]
+  if (!include_na) {
+    x <- x |> tidyr::drop_na()
+  }
+  p <- ggplot2::ggplot(
+    x,
+    ggplot2::aes(
+      x = !!rlang::sym("time"),
+      y = !!rlang::sym(".seq_id")
+    )
+  ) +
+    ggplot2::geom_raster(ggplot2::aes(fill = !!rlang::sym("state"))) +
+    ggplot2::scale_fill_manual(
+      values = colors,
+      name = legend_title,
+      na.value = na_color
+    ) +
+    ggplot2::scale_x_discrete(breaks = every_nth) +
+    ggplot2::labs(title = title, x = xlab, y = ylab) +
+    ggplot2::theme_minimal() +
+    ggplot2::theme(
+      panel.grid = ggplot2::element_blank(),
+      axis.text.y = ggplot2::element_blank(),
+      axis.ticks.y = ggplot2::element_blank(),
+      legend.position = "right"
+    )
+  if (!missing(border)) {
+    p <- p + ggplot2::geom_tile(
+      ggplot2::aes(fill = !!rlang::sym("state")),
+      color = border,
+      linewidth = 0.1,
+      na.rm = FALSE
+    )
+  }
+  if (!missing(group)) {
+    p <- p + ggplot2::facet_wrap(
+      ggplot2::vars(!!rlang::sym(group)),
+      ncol = ncol,
+      scales = "free_y",
+    )
+  }
+  p
+}
+
+create_distribution_plot <- function(x, group, scale, geom, include_na,
+                                     colors, na_color, border, title, title_n,
+                                     legend_title, xlab, ylab, tick, ncol) {
+  xlab <- ifelse_(missing(xlab), "Time", xlab)
+  ylab <- ifelse_(
+    missing(ylab),
+    ifelse_(scale == "proportion", "Proportion", "Count"),
+    ylab
+  )
+  title <- ifelse_(missing(title), "\"Sequence Distribution Plot \"", title)
+  title <- str2expression(paste0(title, " * ", title_n))
+  legend_title <- ifelse_(missing(legend_title), NULL, legend_title)
+  every_nth <- function(y) y[(seq_along(y) - 1L) %% tick == 0]
+  position <- ifelse_(scale == "proportion", "fill", "stack")
+  if (!include_na) {
+    x <- x |> tidyr::drop_na()
+  }
+  if (geom == "bar") {
+    p <- ggplot2::ggplot(
+      x,
+      ggplot2::aes(
+        x = !!rlang::sym("time"),
+        fill = !!rlang::sym("state")
+      )
+    )+
+      ggplot2::geom_bar(na.rm = FALSE, width = 1, position = position) +
+      ggplot2::scale_x_discrete(breaks = every_nth)
+  } else if (geom == "area") {
+    time_levels <- levels(x$time)
+    x$time <- as.numeric(x$time)
+    p <- ggplot2::ggplot(
+      x,
+      ggplot2::aes(
+        x = !!rlang::sym("time"),
+        fill = !!rlang::sym("state")
+      )
+    )+
+      ggplot2::geom_area(position = position, stat = "count") +
+      ggplot2::scale_x_continuous(
+        breaks = every_nth(seq_along(time_levels)),
+        labels = every_nth(time_levels)
+      )
+  }
+  p <- p +
+    ggplot2::scale_fill_manual(
+      values = colors,
+      name = legend_title,
+      na.value = na_color
+    ) +
+    ggplot2::labs(title = title, x = xlab, y = ylab) +
+    ggplot2::theme_minimal() +
+    ggplot2::scale_y_reverse() +
+    ggplot2::theme(
+      panel.grid = ggplot2::element_blank(),
+      axis.text.y = ggplot2::element_blank(),
+      axis.ticks.y = ggplot2::element_blank(),
+      legend.position = "right"
+    )
+  if (!missing(group)) {
+    p <- p + ggplot2::facet_wrap(
+      ggplot2::vars(!!rlang::sym(group)),
+      ncol = ncol,
+      scales = "free_y"
+    )
+  }
+  p
+}
+
 #' Create a heatmap from edgelist data
 #'
 #' @param data A `data.frame` with source and target columns and edge weights.
@@ -1092,7 +1521,7 @@ create_heatmap <- function(data, title) {
       x = !!rlang::sym("target"),
       y = !!rlang::sym("source"),
       fill = !!rlang::sym("value")
-  )) +
+    )) +
     ggplot2::geom_tile() +
     ggplot2::scale_fill_gradient2(
       low = "blue",
@@ -1110,7 +1539,7 @@ create_heatmap <- function(data, title) {
     )
 }
 
-# Clusters ----------------------------------------------------------------
+# Groups ----------------------------------------------------------------
 
 #' Plot a Histogram of Edge Weights for a `group_tna` Object.
 #'
@@ -1119,7 +1548,7 @@ create_heatmap <- function(data, title) {
 #' @param x A `group_tna` object.
 #' @param ... Additional arguments passed to [graphics::hist()].
 #' @return A `list` (invisibly) of `histogram` objects of the edge weights of
-#' each cluster.
+#'   each cluster.
 #' @examples
 #' model <- group_model(engagement_mmm)
 #' hist(model)
@@ -1138,11 +1567,12 @@ hist.group_tna <- function(x, ...) {
 #' @family basic
 #' @param x A `group_model` object.
 #' @param title A title for each plot. It can be a single string (the same one
-#'  will be used for all plots) or a list (one per group)
+#'   will be used for all plots) or a list (one per group)
 #' @param which An optional `integer` vector of groups to plot. By default, all
-#' groups are plotted.
+#'   groups are plotted.
 #' @param ... Same as [plot.tna()].
 #' @return `NULL` (invisibly).
+#' @inheritDotParams plot.tna
 #' @examples
 #' model <- group_model(engagement_mmm)
 #' plot(model)
@@ -1171,6 +1601,7 @@ plot.group_tna <- function(x, title, which, ...) {
 #' @export
 #' @family validation
 #' @param x A `group_tna_bootstrap` object.
+#' @param title A `character` vector of titles to use for each plot.
 #' @param ... Additional arguments passed to [plot.tna()].
 #' @examples
 #' model <- group_model(engagement_mmm)
@@ -1178,7 +1609,7 @@ plot.group_tna <- function(x, title, which, ...) {
 #' boot <- bootstrap(model, iter = 50)
 #' plot(boot)
 #'
-plot.group_tna_bootstrap <- function(x, ...) {
+plot.group_tna_bootstrap <- function(x, title = names(x), ...) {
   check_missing(x)
   check_class(x, "group_tna_bootstrap")
   invisible(lapply(x, plot.tna_bootstrap, ...))
@@ -1189,6 +1620,7 @@ plot.group_tna_bootstrap <- function(x, ...) {
 #' @export
 #' @family centralities
 #' @param x A `group_tna_centralities` object.
+#' @param palette A color palette to be applied if `colors` is not specified.
 #' @inheritParams plot.tna_centralities
 #' @return A `ggplot` object displaying a line chart for each centrality
 #' with one line per cluster.
@@ -1199,10 +1631,11 @@ plot.group_tna_bootstrap <- function(x, ...) {
 #'
 plot.group_tna_centralities <- function(x, reorder = TRUE, ncol = 3,
                                         scales = c("free_x", "fixed"),
-                                        colors, labels = TRUE, ...) {
+                                        colors, palette = "Set2",
+                                        labels = TRUE, ...) {
   check_missing(x)
   check_class(x, "group_tna_centralities")
-  plot_centralities_(x, reorder, ncol, scales, colors, labels)
+  plot_centralities_(x, reorder, ncol, scales, colors, palette, labels)
 }
 
 #' Plot Found Cliques
@@ -1262,7 +1695,7 @@ plot.group_tna_communities <- function(x, title = names(x), colors, ...) {
     )
   )
   if (is.null(title) ||
-    (is.vector(title) && is.atomic(title) && (length(title) == 1))) {
+      (is.vector(title) && is.atomic(title) && (length(title) == 1))) {
     title <- replicate(n, title, simplify = FALSE)
   }
   invisible(
@@ -1329,12 +1762,12 @@ plot.group_tna_permutation <- function(x, title, ...) {
   invisible(
     lapply(
       seq_along(x),
-      function(i) plot.tna_permutation(x[[i]], title = title[i])
+      function(i) plot.tna_permutation(x[[i]], title = title[i], ...)
     )
   )
 }
 
-#' Plot the Difference Network Between Two Clusters
+#' Plot the Difference Network Between Two Groups
 #'
 #' @export
 #' @family comparison
@@ -1365,45 +1798,96 @@ plot_compare.group_tna <- function(x, i = 1L, j = 2L, ...) {
 #' @param label An optional `character` string that can be provided to specify
 #' the grouping factor name if `x` was not constructed using a column name of
 #' the original data.
+#' @param colors A vector of colors to be used in the plot (one per group)
+#' @param palette A palette to be used if colors are not passed.
+#' @param width Width of the bars. Default is 0.7.
+#' @param hjust Horizontal adjustment of the labels. Default is 1.2.
+#' @param position Position of the bars: "dodge", "dodge2", "fill" or "stack"
+#' @param show_label Boolean indicating whether to show a label with the
+#'  frequency counts. Default is `TRUE`.
 #' @param ... Ignored.
 #' @return A `ggplot` object.
 #' @examples
 #' model <- group_model(engagement_mmm)
+#' # Default
 #' plot_frequencies(model)
+#' # Default labels outside and custom colors
+#' plot_frequencies(
+#'   model,
+#'   width = 0.9,
+#'   hjust = -0.3,
+#'   colors = c("#218516", "#f9c22e", "#53b3cb")
+#' )
+#' # Stacked with no labels
+#' plot_frequencies(model, position = "stack", show_label = FALSE)
+#' # Fill
+#' plot_frequencies(model, position = "fill", hjust = 1.1)
 #'
-plot_frequencies.group_tna <- function(x, label, ...) {
+plot_frequencies.group_tna <- function(x, label, colors, width = 0.7,
+                                       palette = "Set2",
+                                       show_label = TRUE, position = "dodge",
+                                       hjust = 1.2, ...) {
   check_missing(x)
   check_class(x, "group_tna")
-  combined <- combine_data(x, label)
-  long <- combined$data
-  label <- combined$label
-  long$value <- factor(x[[1L]]$labels[long$value])
-  long[[label]] <- factor(long[[label]])
+  label <- ifelse_(missing(label), attr(x, "label"), label)
+  combined <- combine_data(x)
+  long <- tidyr::pivot_longer(combined, cols = !(!!rlang::sym(".group")))
+  check_values(width, type = "numeric")
+  check_numeric(hjust)
+  check_flag(show_label)
+  long$value <- factor(x[[1L]]$labels[long$value], levels = rev(x[[1L]]$labels))
+  long$.group <- factor(long$.group)
+  position <- check_match(position, c("dodge", "dodge2", "fill", "stack"))
+  position <- switch(position,
+                     dodge = ggplot2::position_dodge(width = width),
+                     dodge2 = ggplot2::position_dodge2(width = width),
+                     stack = "stack",
+                     fill = "fill"
+  )
   d <- long |>
-    dplyr::group_by(!!rlang::sym(label), !!rlang::sym("value")) |>
-    dplyr::summarize(freq = dplyr::n())
-  ggplot2::ggplot(
+    dplyr::group_by(!!rlang::sym(".group"), !!rlang::sym("value")) |>
+    dplyr::summarize(freq = dplyr::n()) |>
+    dplyr::ungroup() |>
+    dplyr::filter(!is.na(!!rlang::sym("value")))
+
+  p <- ggplot2::ggplot(
     d,
     ggplot2::aes(
-      x = !!rlang::sym("value"),
-      y = !!rlang::sym("freq"),
-      fill = !!rlang::sym(label))
+      y = !!rlang::sym("value"),
+      x = !!rlang::sym("freq"),
+      fill = !!rlang::sym(".group"))
   ) +
     ggplot2::geom_bar(
       stat = "identity",
       colour = "black",
-      position = ggplot2::position_dodge(),
-      width = 0.7
-    ) +
-    ggplot2::geom_text(
-      ggplot2::aes(label = !!rlang::sym("freq")),
-      position = ggplot2::position_dodge(width = 0.7),
-      vjust = -0.5
-    ) +
-    ggplot2::scale_fill_brewer(palette = "Set2") +
+      position = position,
+      width = width
+    )
+  if(show_label) {
+    p <- p +
+      ggplot2::geom_text(
+        ggplot2::aes(label = !!rlang::sym("freq")),
+        position = position,
+        hjust = hjust
+      )
+  }
+  if (!missing(colors)) {
+    colors <- rep(colors, length.out = length(x))
+    p <- p + ggplot2::scale_fill_manual(name = label, values = colors)
+  } else {
+    p <- p + ggplot2::scale_fill_brewer(name = label, palette = palette)
+  }
+  p +
     ggplot2::theme_minimal() +
-    ggplot2::scale_y_continuous(expand = ggplot2::expansion(mult = c(0, .1))) +
-    ggplot2::labs(x = "State", y = "Frequency")
+    ggplot2::scale_x_continuous(
+      expand = ggplot2::expansion(mult = c(0, 0.1))
+    ) +
+    ggplot2::labs(y = "State", x = "Frequency") +
+    ggplot2::theme(
+      legend.position =  "bottom",
+      axis.title =  ggplot2::element_text(face = "bold"),
+      axis.text = ggplot2::element_text(color = "black"),
+      text = ggplot2::element_text(color = "black"))
 }
 
 #' Plot State Frequencies as a Mosaic Between Two Groups
@@ -1451,20 +1935,15 @@ plot_mosaic.tna_data <- function(x, group, label = "Group", digits = 1, ...) {
       "Argument {.arg group} must be a column name of the input data
        when of length one."
     )
-    label <- group
     group <- x$meta_data[[group]]
   }
-  group <- ifelse_(
-    is.factor(group),
-    group,
-    factor(group)
-  )
+  group <- ifelse_(is.factor(group), group, factor(group))
   wide <- cbind(x$sequence_data, group)
-  names(wide) <- c(names(x$sequence_data), label)
+  names(wide) <- c(names(x$sequence_data), ".group")
   long <- wide |>
-    tidyr::pivot_longer(cols = !(!!rlang::sym(label))) |>
+    tidyr::pivot_longer(cols = !(!!rlang::sym(".group"))) |>
     tidyr::drop_na()
-  tab <- table(long[[label]], long$value)
+  tab <- table(long$.group, long$value)
   plot_mosaic_(
     tab,
     digits,
@@ -1493,12 +1972,12 @@ plot_mosaic.group_tna <- function(x, label, digits = 1, ...) {
   check_missing(x)
   check_class(x, "group_tna")
   check_values(digits, strict = TRUE)
-  combined <- combine_data(x, label)
-  long <- combined$data
-  label <- combined$label
+  label <- ifelse_(missing(label), attr(x, "label"), label)
+  combined <- combine_data(x)
+  long <- tidyr::pivot_longer(combined, cols = !(!!rlang::sym(".group")))
   labels <- x[[1L]]$labels
   use_na <- ifelse_(attr(x, "na.rm"), "no", "ifany")
-  tab <- table(long[[label]], long$value, useNA = use_na)
+  tab <- table(long$.group, long$value, useNA = use_na)
   dimnames(tab) <- list(attr(x, "levels"), labels)
   plot_mosaic_(
     tab,
@@ -1508,3 +1987,25 @@ plot_mosaic.group_tna <- function(x, label, digits = 1, ...) {
     ylab = "State"
   )
 }
+
+#' @export
+#' @rdname plot_sequences
+plot_sequences.group_tna <- function(x, type = "index", scale = "proportion",
+                                     geom = "bar", include_na = FALSE,
+                                     na_color = "white", sort_by, show_n = TRUE,
+                                     border, title, legend_title, xlab, ylab,
+                                     tick = 1, ncol = 2L, ...) {
+  check_missing(x)
+  check_class(x, "group_tna")
+  d <- combine_data(x)
+  cols <- setdiff(names(d), ".group")
+  group <- ".group"
+  colors <- attr(x[[1L]]$data, "colors")
+  lab <- x[[1L]]$labels
+  lev <- seq_along(lab)
+  plot_sequences_(
+    d, lev, lab, cols, group, type, scale, geom, include_na, colors,
+    na_color, sort_by, show_n, border, title, legend_title,
+    xlab, ylab, tick, ncol
+  )
+}
